@@ -17,8 +17,7 @@ vm.kde <- function(u, h = NULL, thumb = "none", rads = TRUE) {
   ## thumb is either 'none' (defualt), or 'tay' (Taylor, 2008) or
   ## 'rot' (Garcia-Portugues, 2013)
   ## if the data are in degrees we transform them into radians
-
-  if (rads == FALSE)  u <- u / 180 * pi
+  if ( rads )  u <- u / 180 * pi
   n <- length(u)  ## sample size
   x <- cbind( cos(u), sin(u) )
   disa <- tcrossprod(x)
@@ -31,12 +30,10 @@ vm.kde <- function(u, h = NULL, thumb = "none", rads = TRUE) {
       k <- circ.summary(u, rads = TRUE, plot = FALSE)$kappa
       h <- ( 4 * pi^0.5 * besselI(k, 0)^2 / (3 * n * k^2 *
       besselI(2 * k, 2)) )^0.2
-
     } else if (thumb == "rot") {
       k <- circ.summary(u, rads = TRUE, plot = FALSE)$kappa
       h <- ( 4 * pi^0.5 * besselI(k, 0)^2 / ( k * n * ( 2 * besselI(2 * k, 1) +
       3 * k * besselI(2 * k, 2)) ) )^0.2
-
     } else if (thumb == "none") {
       h <- as.numeric( vmkde.tune(u, low = 0.1, up = 1)[1] )
     }
@@ -44,6 +41,5 @@ vm.kde <- function(u, h = NULL, thumb = "none", rads = TRUE) {
   } else h <- h
 
   f <- Rfast::rowsums( expa^( 1 / h^2 ) ) / ( n * 2 * pi * besselI(1/h^2, 0) )
-
   list( h = h, f = f )
 }
